/**
 ** A Virtual Host Monitor
 **
 ** Copyright 2009 Gary Wuertz gary@issiweb.com
 **
 ** This program is free software: you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
 ** the Free Software Foundation, either version 3 of the License, or
 ** (at your option) any later version.
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ** GNU General Public License for more details.
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef TOPVHOST_MONITOR_H
#define TOPVHOST_MONITOR_H

#include <vector>

#include <sys/types.h>
#include "config.h"
#include "vhost.h"
#include "topvhost.h"
/**
 * The watchlist enumerates what will be watched
 */
class watchList {
public:
 watchList() : success(false), problem(""), namelen(0) { }
 bool                               success;    // good to go indication
 std::string                        problem;    // failure report
 int                                namelen;    // length of longest domain name
 std::map<std::string,std::string>  watch;      // domain=>logfile
};
/**
 * Monitor options
 */
struct monitorOptions {
  char*  configFile;      // configuration file
  char*  configSection;   // config file section
  bool   init;            // read logs at startup
  bool   verify;          // verify settings
};
/**
 * The vhost monitor
 */
class Monitor
{
public:
  bool                      success;
  std::string               problem;
  Config*                   conf;
  std::map<int,std::string> rmap;

  vhost*                    getHosts(topvhost *info);
  watchList*                getWatchList(Config * conf);
  bool                      init(topvhost *info, struct monitorOptions options);
  std::vector<std::string>* parseApacheLogFormat(Config *conf);
  void                      quit(void);
  void                      refresh(void);
  bool                      setError(char *tag);
  bool                      update(void);
private:
  int                       namelen;          // max domain name length
  int                       notify;           // inotify file handle
  int                       nhosts;           // number of vhosts
  vhost*                    hosts;            // the vhosts
  vhost*                    hlist;            // the sorted vhost list
};
#endif
