/**
 ** A Virtual Host Monitor
 **
 ** Copyright 2009 Gary Wuertz gary@issiweb.com
 **
 ** This program is free software: you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
 ** the Free Software Foundation, either version 3 of the License, or
 ** (at your option) any later version.
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ** GNU General Public License for more details.
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef TOPVHOST_VHOST_H
#define TOPVHOST_VHOST_H

#include <map>
#include <string>

#include "topvhost.h"
/**
 * Representation of a vhost
 */
class vhost {
public:
  enum {
    PARSE_SLOT,               // for debug tracing
    IP_SLOT,                  // Remote IP
    REQUEST_SLOT,             // Request string
    SLOT_SIZE                 // number of record args
  };
  std::string domain;         // Domain name
  std::string file;           // File name
  std::string rec[SLOT_SIZE]; // log record arguments
  bool        dirty;          // dirty bit
  bool        iq;             // quote flag
  int         argn;           // record number
  int         hits;           // hits this domain
  int         wd;             // notify displacement
  off_t       fsz;            // size of log file
  time_t      ldtm;           // time of last access
  long        meter;          // for metering

  vhost() : dirty(false),iq(false),argn(0),hits(0),wd(0),fsz(0),ldtm(0),meter(0) { }
  void        parseLogRecord(const std::map<int,std::string>* rmap,char *s, int ct);
  bool        setClean(const std::map<int,std::string>* rmap);
  bool        setDirty(bool init=true);
  void        toString(topvhost *info);
};
#endif
